@@ -264,7 +264,8 @@ test_that("bonsai correctly determines objective when label is a factor", {
         bst <- train_lightgbm(
             x = penguins[, c("bill_length_mm", "bill_depth_mm")],
             y = penguins[["sex"]],
-            num_iterations = 5
+            num_iterations = 5,
+            verbose = -1L
         )
     })
     expect_equal(bst$params$objective, "binary")
@@ -274,7 +275,8 @@ test_that("bonsai correctly determines objective when label is a factor", {
         bst <- train_lightgbm(
             x = penguins[, c("bill_length_mm", "bill_depth_mm")],
             y = penguins[["species"]],
-            num_iterations = 5
+            num_iterations = 5,
+            verbose = -1L
         )
     })
     expect_equal(bst$params$objective, "multiclass")
@@ -475,13 +477,44 @@ test_that("training wrapper warns on protected arguments", {
     boost_tree() %>%
       set_engine(
         "lightgbm",
-        colnames = paste0("X", 1:ncol(penguins)),
-        nrounds = 50
+        colnames = paste0("X", 1:ncol(penguins))
       ) %>%
       set_mode("regression") %>%
       fit(bill_length_mm ~ ., data = penguins),
     "guarded by bonsai.*colnames"
   )
+
+  expect_snapshot(
+    error = TRUE,
+    boost_tree() %>%
+      set_engine("lightgbm", n_iter = 10) %>%
+      set_mode("regression") %>%
+      fit(bill_length_mm ~ ., data = penguins)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    boost_tree() %>%
+      set_engine("lightgbm", num_tree = 10) %>%
+      set_mode("regression") %>%
+      fit(bill_length_mm ~ ., data = penguins)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    boost_tree() %>%
+      set_engine("lightgbm", min_split_gain = 2) %>%
+      set_mode("regression") %>%
+      fit(bill_length_mm ~ ., data = penguins)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    boost_tree() %>%
+      set_engine("lightgbm", min_split_gain = 2, lambda_l2 = .5) %>%
+      set_mode("regression") %>%
+      fit(bill_length_mm ~ ., data = penguins)
+  )
 })
 
 test_that("training wrapper passes stop_iter correctly", {
@@ -503,10 +536,10 @@ test_that("training wrapper passes stop_iter correctly", {
   expect_warning(
     pars_fit_2 <-
       boost_tree() %>%
-      set_engine("lightgbm", early_stopping_rounds = 10) %>%
+      set_engine("lightgbm", early_stopping_round = 10) %>%
       set_mode("regression") %>%
       fit(bill_length_mm ~ ., data = penguins),
-    "were removed: early_stopping_rounds"
+    "were removed: early_stopping_round"
   )
 
   expect_error_free(
